
export interface MemoryCacheLimit {
    pc: number;
    mobile: number;
}

export interface WsSignalerAddr {
    main: string;
    backup: string;
}

export enum LogLevel {
    Warn = 'warn',
    Error = 'error',
    None = 'none',
}

export interface P2pConfig {
    logLevel?: LogLevel | boolean;
    wsSignalerAddr?: string | WsSignalerAddr;
    announce?: string;
    announceLocation?: string;
    memoryCacheLimit?: MemoryCacheLimit;
    p2pEnabled?: boolean;
    dcDownloadTimeout?: number;
    webRTCConfig?: any;
    useHttpRange?: boolean;
    httpLoadTime?: number;
    simultaneousTargetPeers?: boolean;
    tag?: string;
    token?: string;
    swFile?: string;
    swScope?: string;
    showSlogan?: boolean;
    trickleICE?: boolean;
    geoIpPreflight?: boolean;
    sharePlaylist?: boolean;
    nativePlaybackOnly?: boolean;
    getStats?: (totalP2PDownloaded: number, totalP2PUploaded: number, totalHTTPDownloaded: number, p2pDownloadSpeed: number)=>void;
    getPeerId?: (peerId: string)=>void;
    getPeersInfo?: (peers: string[])=>void;
    channelId?: (m3u8Url: string)=>string;
    segmentId?: (streamId: string, sn: number, url: string, range: string)=>string;
    validateSegment?: (segId: string, buffer: ArrayBufferLike)=>boolean;
    videoElem?: HTMLVideoElement | string;
}

export declare class P2PEngineIOS {
    static isSupported(): boolean;
    static isMSESupported(): boolean;
    static isWebRTCSupported(): boolean;
    static isSeviceWorkerSupported(): boolean;
    static readonly version: string;
    static readonly protocolVersion: string;
    public readonly version: string;
    constructor(p2pConfig?: P2pConfig);
    registerServiceWorker(): Promise<ServiceWorkerRegistration>;
    unregisterServiceWorker(): Promise<void>;
    enableP2P(): void;
    disableP2P(): void;
    restartP2p(): void;
    destroy(): void;
    on(name: string, func: (...args)=>void);
}

export default P2PEngineIOS;
